bomcheck - troubleshooting

# Troubleshooting

1. CAD BOM not processed.
2. Assembly pn in ERP, but CAD BOM not processed. (e.g., ERP = SyteLine)
3. ERP BOM not processed.
4. Empty I Q D U fields (e.g. " " and not "‒‒‒X‒" or "‒‒‒‒" as should be) .
5. SW's lengths not converted to FT.
6. What accuracy should lengths be?
7. U/M (unit of measure) missing for part shown in ERP BOM.
8. A U/M value did not convert properly.
9. Program crashed due to missing columns.
10. Unable to open config.txt file.
11. Pn's description in CAD BOM changed after program ran.
12. CAD BOM and ERP BOM seem to not sync at all.
13. PN is in both the ERP BOM and the CAD BOM, but doesn't appear in bomcheck results???

1. CAD BOM not processed. A CAD BOM I submitted wasn't compared to an ERP BOM. The only thing that happend is that the BOM was transformed to look like a BOM from ERP. What happened? Answer: No ERP BOM was found to compare it to the CAD BOM.

2. Assembly pn in ERP, but CAD BOM not processed. I have a particular assembly/subassembly BOM entered into ERP but the bomcheck program reports that that it cannot find the BOM. Why? For that particular assembly, the parts of that assembly have not been entered yet into ERP.

3. ERP BOM not processed. An ERP BOM was submitted but nothing happened to indicate that the BOM had even been looked at. What happened? Answer: bomcheck ignores all BOMs from ERP for which it can't find a CAD BOM to compare it to.

4. Empty I Q D U fields (e.g. " " and not "‒‒‒X‒" or "‒‒‒‒" as should be). The I, Q, D, and U values that indicate pass/fail results are shown empty If this is not the case then it indicates that a part number is repeated in the ERP BOM. Duplicate part numbers should not be in an ERP BOM!

5. SW's lengths not converted to FT. A part length in CAD did not convert of feet in order to compare to a length in ERP. Why not? If in the CAD check you see that the unit of measure for length is EA when it should be FT, it means that the length column is not shown on the CAD BOM.

6. What accuracy should lengths be? If you are running the bomcheckgui program, at File > Settings the decimal place accuracy is set for rounding bomcheck lengths (e.g. .83 ft). An accuracy of 2 (for feet) is a good number. This means that if two places are shown, then the length is accurate to within ±0.06 inches. This is close enough. Then if the lengths shown in CAD and ERP differ by more than ±0.06 inches, then bomcheck will flag this as an error. Of course, a greater level of accuracy can be set.

7. U/M (unit of measure) missing for part shown in ERP BOM. Someone forgot to enter the U/M into ERP.

8. A U/M value did not convert properly. In the LENGTH column I put 56 SQ. IN., Bomcheck should convert it to square feet. Right? Yes, it should, but SQ. IN. is not a unit of measure that bomcheck will recognize. To see units of measure that will be recognized, see Units of Measure in bomcheck's help section 1.

9. Program crashed due to missing columns. Bomcheck crashed complaining of missing columns. What went wrong? Answer: several things could have happened. An ERP BOM may have been mistakenly labeled as as CAD BOM (i.e., had _sw.xlsx extension). A CAD BOM may have been labeled as an ERP BOM (i.e., had a _sl.xlsx extension). In short, the arrangement of the BOM in the Excel sheet is not correct.

10. Unable to open config.txt (bomcheckgui only) The program reports that it cannot open up a file named config.txt. What is that about? Answer: Whenever a user makes a settings change (File > Settings), bomcheckgui remembers those settings for future use by saving those settings in a file named config.txt. That file is located in a user's settings folder. The file is at C:\Users\username\AppData\Local\bomcheck\config.txt. (The bomcheckgui program automatically creates this file.) Perhaps user rights were somehow severed??? Contact the IT manager for help.

11. Pn's description in CAD BOM changed after program ran. You have two or more parts or part configurations that are configured to show the same part number on a CAD BOM. As an example, two hoses with different bends, but with same length and same end fittings should report the same part number on a CAD BOM. But the two hoses come from two different CAD solid model files or configurations. The two models/configs should, obviously, have the same descriptions assigned. But you may have mistakenly put in different descriptions. When the bomcheck program is run, it combines quantities of hoses and picks one of the two descriptions to compare to the ERP description. Bomcheck could pick the part with the wrong description. Bomcheck does not check to see if descriptions are different between models or configurations. That is up to you to catch and correct.

12. CAD BOM and ERP BOM seem to not sync at all. When you pulled a multilevel BOM from the ERP, you may have mistakenly pushed the sort button on the LEVEL column or some other column within the ERP's BOM. The button to sort and to extract an Excel file are close together and you mistakenly pushed the sort. Close the ERP BOM and derive the BOM again. Yet another posible reason that things are not working out is that you misnamed a _sw.xlsx file to a _sl.xlsx file, or vice-versa.

13. PN is in both the ERP BOM and the CAD BOM, but doesn't appear in bomcheck results??? I have a part no. in the CAD BOM, and I have the same PN in the ERP (overview) BOM, but when I run bomcheck, the PN doesn't appear on the ERP's side of the results. So why in my PN not showing? In the ERP overview BOM, look for the column named Obsolete Date. If there is any text in that column for a PN, then bomcheck will not use that PN when it runs. To use that PN in your evaluation, erase any text in that column for that particular PN.

Note: The obsolete column along with entries thereof is never shown in a multilevel BOM

last updated: 3/23/2024